pub struct FormatRegistry { /* private fields */ }Expand description
Implementations
Sourceimpl FormatRegistry
impl FormatRegistry
Sourcepub fn register<F: Format + 'static>(&mut self, format: F)
pub fn register<F: Format + 'static>(&mut self, format: F)
Register a format
If a format with the same name already exists, it will be replaced.
Sourcepub fn list_formats(&self) -> Vec<String>
pub fn list_formats(&self) -> Vec<String>
List all available format names (sorted)
Sourcepub fn detect_format_from_filename(&self, filename: &str) -> Option<String>
pub fn detect_format_from_filename(&self, filename: &str) -> Option<String>
Detect format from filename based on file extension
Returns the format name if a matching extension is found, or None otherwise.
Examples
ⓘ
let registry = FormatRegistry::default();
assert_eq!(registry.detect_format_from_filename("doc.lex"), Some("lex".to_string()));
assert_eq!(registry.detect_format_from_filename("doc.md"), Some("markdown".to_string()));
assert_eq!(registry.detect_format_from_filename("doc.unknown"), None);Sourcepub fn parse(&self, source: &str, format: &str) -> Result<Document, FormatError>
pub fn parse(&self, source: &str, format: &str) -> Result<Document, FormatError>
Parse source text using the specified format
Sourcepub fn serialize(
&self,
doc: &Document,
format: &str,
) -> Result<String, FormatError>
pub fn serialize( &self, doc: &Document, format: &str, ) -> Result<String, FormatError>
Serialize a document using the specified format
Sourcepub fn serialize_with_options(
&self,
doc: &Document,
format: &str,
options: &HashMap<String, String>,
) -> Result<SerializedDocument, FormatError>
pub fn serialize_with_options( &self, doc: &Document, format: &str, options: &HashMap<String, String>, ) -> Result<SerializedDocument, FormatError>
Serialize a document using the specified format and options
Sourcepub fn with_defaults() -> Self
pub fn with_defaults() -> Self
Create a registry with default formats